NAME
Module::CPANTS::Kwalitee::Distname - Proper Distname layout
SYNOPSIS
Checks if a distname is well-formed.
A wellformed distname looks like Foo-Bar-1.42.tgz
DESCRIPTION
Methods
order
Defines the order in which Kwalitee tests should be run.
Returns 20, as data generated by MCK::Distname is used by other tests.
analyse
MCK::Distname uses CPAN::DistnameInfo to split a distname into it's components.
kwalitee_indicators
Returns the Kwalitee Indicators datastructure.
has_version
has_proper_version
SEE ALSO
AUTHOR
Thomas Klausner, <domm@cpan.org>, http://domm.zsi.at
COPYRIGHT
You may use and distribute this module according to the same terms that Perl is distributed under.